Module: wine
Branch: master
Commit: 22d3e6dba1a2cc3fa891be9d1121697e541860b1
URL: http://source.winehq.org/git/wine.git/?a=commit;h=22d3e6dba1a2cc3fa891be9d1…
Author: Henri Verbeet <hverbeet(a)codeweavers.com>
Date: Tue Mar 27 20:35:49 2012 +0200
winex11: Use GLX_DONT_CARE instead of ~0 in ConvertAttribWGLtoGLX().
---
dlls/winex11.drv/opengl.c | 12 ++++++------
1 files changed, 6 insertions(+), 6 deletions(-)
diff --git a/programs/winedbg/db_disasm.c b/programs/winedbg/db_disasm.c
index e2270fc..c745617 100644
--- a/programs/winedbg/db_disasm.c
+++ b/programs/winedbg/db_disasm.c
@@ -1334,7 +1334,7 @@ void be_i386_disasm_one_insn(ADDRESS64 *addr, int display)
struct i_addr address;
/*
- * Set this so we get can suppress the printout if we need to.
+ * Set this so we can suppress the printout if we need to.
*/
db_display = display;
switch (addr->Mode)
diff --git a/dlls/winex11.drv/opengl.c b/dlls/winex11.drv/opengl.c
index e8d0f89..e25e082 100644
--- a/dlls/winex11.drv/opengl.c
+++ b/dlls/winex11.drv/opengl.c
@@ -680,7 +680,7 @@ static int ConvertAttribWGLtoGLX(const int* iWGLAttr, int* oGLXAttr, Wine_GLPBuf
int pop;
int drawattrib = 0;
int nvfloatattrib = GLX_DONT_CARE;
- int pixelattrib = ~0;
+ int pixelattrib = GLX_DONT_CARE;
/* The list of WGL attributes is allowed to be NULL. We don't return here for NULL
* because we need to do fixups for GLX_DRAWABLE_TYPE/GLX_RENDER_TYPE/GLX_FLOAT_COMPONENTS_NV. */
@@ -876,15 +876,15 @@ static int ConvertAttribWGLtoGLX(const int* iWGLAttr, int* oGLXAttr, Wine_GLPBuf
}
/* By default glXChooseFBConfig defaults to GLX_WINDOW_BIT. wglChoosePixelFormatARB searches through
- * all formats. Unless drawattrib is set to a non-zero value override it with ~0, so that pixmap and pbuffer
- * formats appear as well. */
- if(!drawattrib) drawattrib = ~0;
+ * all formats. Unless drawattrib is set to a non-zero value override it with GLX_DONT_CARE, so that
+ * pixmap and pbuffer formats appear as well. */
+ if (!drawattrib) drawattrib = GLX_DONT_CARE;
PUSH2(oGLXAttr, GLX_DRAWABLE_TYPE, drawattrib);
TRACE("pAttr[?] = GLX_DRAWABLE_TYPE: %#x\n", drawattrib);
/* By default glXChooseFBConfig uses GLX_RGBA_BIT as the default value. Since wglChoosePixelFormatARB
* searches in all formats we have to do the same. For this reason we set GLX_RENDER_TYPE to ~0 unless
* it is overridden. */
PUSH2(oGLXAttr, GLX_RENDER_TYPE, pixelattrib);
TRACE("pAttr[?] = GLX_RENDER_TYPE: %#x\n", pixelattrib);
Module: wine
Branch: master
Commit: db8d76034d7125415ddcb0ca5896ea1e73db6bf6
URL: http://source.winehq.org/git/wine.git/?a=commit;h=db8d76034d7125415ddcb0ca5…
Author: André Hentschel <nerv(a)dawncrow.de>
Date: Sun Mar 25 12:33:49 2012 +0200
winedbg: Fix a typo.
---
programs/winedbg/db_disasm.c | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
@@ -876,15 +876,15 @@ static int ConvertAttribWGLtoGLX(const int* iWGLAttr, int* oGLXAttr, Wine_GLPBuf
TRACE("pAttr[?] = GLX_DRAWABLE_TYPE: %#x\n", drawattrib);
/* By default glXChooseFBConfig uses GLX_RGBA_BIT as the default value. Since wglChoosePixelFormatARB
- * searches in all formats we have to do the same. For this reason we set GLX_RENDER_TYPE to ~0 unless
- * it is overridden. */
+ * searches in all formats we have to do the same. For this reason we set GLX_RENDER_TYPE to
+ * GLX_DONT_CARE unless it is overridden. */
PUSH2(oGLXAttr, GLX_RENDER_TYPE, pixelattrib);
TRACE("pAttr[?] = GLX_RENDER_TYPE: %#x\n", pixelattrib);